bayespy.inference.vmp.transformations.RotateSwitchingMarkovChain.setup
======================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateSwitchingMarkovChain.setup